Package: cfToolsData
Title: ExperimentHub data for the cfTools package
Version: 1.8.0
Authors@R: c(
    person(given = "Ran",
        family = "Hu",
        role = c("aut", "cre"),
        email = "huran@ucla.edu",
        comment = c(ORCID = "0000-0002-0563-8957")),
    person("Shuo", "Li", 
        role = "aut",
        comment = c(ORCID = "0000-0002-1960-6016")),
    person(c("Xianghong", "Jasmine"), "Zhou", 
        role = "aut", 
        email = "XJZhou@mednet.ucla.edu", 
        comment = c(ORCID = "0000-0002-4522-7490")),
    person("Wenyuan", "Li", 
        role = "aut",
        email = "WenyuanLi@mednet.ucla.edu",
        comment = c(ORCID = "0000-0002-5029-8525")))
Description: The cfToolsData package supplies the data for the cfTools package. 
    It contains two pre-trained deep neural network (DNN) models for the cfSort 
    function. Additionally, it includes the shape parameters of beta 
    distribution characterizing methylation markers associated with four tumor 
    types for the CancerDetector function, as well as the parameters 
    characterizing methylation markers specific to 29 primary human tissue 
    types for the cfDeconvolve function.
License: file LICENSE
Encoding: UTF-8
Depends: R (>= 4.3.0)
RoxygenNote: 7.2.3
VignetteBuilder: knitr
Imports: utils, ExperimentHub
Suggests: BiocStyle, knitr, rmarkdown, ExperimentHubData, testthat (>=
        3.0.0)
biocViews: ExperimentHub, ExperimentData, ReproducibleResearch,
        DiseaseModel, CancerData, Tissue
URL: https://github.com/jasminezhoulab/cfToolsData
BugReports: https://github.com/jasminezhoulab/cfToolsData/issues
git_url: https://git.bioconductor.org/packages/cfToolsData
git_branch: RELEASE_3_22
git_last_commit: d98a4c0
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 15:14:52 UTC; biocbuild
Author: Ran Hu [aut, cre] (ORCID: <https://orcid.org/0000-0002-0563-8957>),
  Shuo Li [aut] (ORCID: <https://orcid.org/0000-0002-1960-6016>),
  Xianghong Jasmine Zhou [aut] (ORCID:
    <https://orcid.org/0000-0002-4522-7490>),
  Wenyuan Li [aut] (ORCID: <https://orcid.org/0000-0002-5029-8525>)
Maintainer: Ran Hu <huran@ucla.edu>
