---
title: "cfToolsData package"
author: 
  - name: Ran Hu
    affiliation:
      - Department of Pathology and Laboratory Medicine, UCLA
      - Institute for Quantitative and Computational Biosciences, UCLA
      - Bioinformatics Interdepartmental Graduate Program, UCLA
    email: huran@ucla.edu
  - name: Shuo Li
    affiliation:
      - Department of Pathology and Laboratory Medicine, UCLA
  - name: Xianghong Jasmine Zhou
    affiliation:
      - Department of Pathology and Laboratory Medicine, UCLA
      - Institute for Quantitative and Computational Biosciences, UCLA
  - name: Wenyuan Li
    affiliation:
      - Department of Pathology and Laboratory Medicine, UCLA
package: cfToolsData
output: 
  BiocStyle::html_document:
    toc: true
    toc_float: true
    theme: flatly
    highlight: zenburn
  BiocStyle::pdf_document: default
vignette: |
  %\VignetteIndexEntry{cfToolsData}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

The `r Biocpkg("cfToolsData")` package provides two pre-trained deep neural 
network (DNN) models for the *cfSort()* function in `r Biocpkg("cfTools")`.

```{r, message=FALSE}
library(cfToolsData)
models <- c(DNN1(), DNN2())
names(models) <- c("DNN1", "DNN2")
models
```

Users can locate the data file at the specified output file path.

It also provides the shape parameters of beta distribution characterizing 
methylation markers associated with four cancer types for the 
*CancerDetector()* function in `r Biocpkg("cfTools")`.

```{r, message=FALSE}
tumorMarkerParams <- c(
    COAD.tumorMarkerParams.hg19(),
    LIHC.tumorMarkerParams.hg19(),
    LUNG.tumorMarkerParams.hg19(),
    STAD.tumorMarkerParams.hg19()
)
names(tumorMarkerParams) <- c(
    "COAD.tumorMarkerParams",
    "LIHC.tumorMarkerParams",
    "LUNG.tumorMarkerParams",
    "STAD.tumorMarkerParams"
)
tumorMarkerParams
```

Additionally, it includes the shape parameters of beta distribution 
characterizing methylation markers specific to 29 primary human tissue types 
for the *cfDeconvolve()* function in `r Biocpkg("cfTools")`, as well as the 
annotations of these markers.

```{r, message=FALSE}
tissueMarkerParams <- tissueMarkerParams.hg19()
tissueMarkerParams

tissueMarkerAnnot <- tissueMarkerParams.annot()
tissueMarkerAnnot
```

# Session information {-}

```{r}
sessionInfo()
```
