% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zzz.R
\name{DNN1}
\alias{DNN1}
\title{Model DNN1}
\value{
Downloads and caches a `.h5` file in HDF5 format.
}
\description{
The 1st deep neural network in cfSort.
}
\examples{

modelDNN1 <- DNN1()
modelDNN1

}
