% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zzz.R
\name{DNN2}
\alias{DNN2}
\title{Model DNN2}
\value{
Downloads and caches a `.h5` file in HDF5 format.
}
\description{
The 2nd deep neural network in cfSort.
}
\examples{

modelDNN2 <- DNN2()
modelDNN2

}
